@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpacePublishingCommands|
-|''Version''|0.7.3|
+|''Version''|0.7.4|
 |''Status''|@@beta@@|
 |''Description''|toolbar commands for drafting and publishing|
 |''Author''|Jon Robson|
@@ -27,8 +27,8 @@ tiddlyspace.getTiddlerStatusType = function(tiddler) {
 };
 
 var cmd = config.commands.publishTiddler = {
-	text: "publish",
-	tooltip: "Change the public/private state of this tiddler",
+	text: "make public",
+	tooltip: "Change this private tiddler into a public tiddler",
 	errorMsg: "Error publishing %0: %1",
 
 	isEnabled: function(tiddler) {
@@ -143,6 +143,7 @@ var cmd = config.commands.publishTiddler = {
 									callback(info);
 								}
 								store.setDirty(_dirty);
+								story.refreshTiddler(newTitle, null, true); // for drafts
 							});
 						} else {
 							if(callback) {
@@ -196,6 +197,7 @@ var cmd = config.commands.publishTiddler = {
 							if(old) {
 								story.displayTiddler(old, newTitle);
 							}
+							story.refreshTiddler(newTitle, null, true); // for case of drafts
 						}
 						if(callback) {
 							callback(info);
@@ -221,28 +223,10 @@ config.commands.changeToPrivate = {
 		var tiddler = store.getTiddler(title);
 		var newBag = cmd.toggleBag(tiddler, "private");
 		var newTiddler = { title: title, fields: { "server.bag": newBag }};
-		cmd.moveTiddler(tiddler, newTiddler, true);
-	}
-};
-config.commands.changeToPublic = {
-	text: "make public",
-	tooltip: "turn this private tiddler into a public tiddler",
-	isEnabled: function(tiddler) {
-		var type = tiddlyspace.getTiddlerStatusType(tiddler);
-		if(!readOnly && type == "private") {
-			return true;
-		} else {
-			return false;
-		}
-	},
-	handler: function(event, src, title) {
-		var tiddler = store.getTiddler(title);
-		var newBag = cmd.toggleBag(tiddler, "public");
-		var publishTitle = tiddler.fields["publish.name"] || title;
-		var newTiddler = { title: publishTitle, fields: { "server.workspace": newBag }};
-		cmd.moveTiddler(tiddler, newTiddler, true);
+		cmd.moveTiddler(tiddler, newTiddler, false);
 	}
 };
+config.commands.changeToPublic = config.commands.publishTiddler;
 
 config.commands.deleteTiddler.deleteResource = function(tiddler, bag, userCallback) {
 	var workspace = "bags/%0".format([bag]);
@@ -326,7 +310,7 @@ config.commands.deletePrivateTiddler = {
 	}
 };
 /* Save as draft command */
-config.commands.saveDraft = {
+var saveDraftCmd = config.commands.saveDraft = {
 	text: "save draft",
 	tooltip: "Save as a private draft",
 	isEnabled: function(tiddler) {
@@ -337,15 +321,7 @@ config.commands.saveDraft = {
 			return false;
 		}
 	},
-	handler: function(ev, src, title) {
-		// TODO: when creating a draft also copy over revisions from the public version
-		var tiddler = store.getTiddler(title); // original tiddler
-		var tidEl = story.getTiddler(title);
-		var fields = {};
-		story.gatherSaveFields(tidEl, fields);
-		var extendedFields = merge({}, config.defaultCustomFields);
-		var currentSpace = tiddlyspace.currentSpace.name;
-		var privateWorkspace = "recipes/%0_private".format([currentSpace]);
+	getDraftTitle: function(title) {
 		var draftTitle;
 		var draftNum = "";
 		while(!draftTitle) {
@@ -356,21 +332,47 @@ config.commands.saveDraft = {
 				draftTitle = suggestedTitle;
 			}
 		}
-
-		extendedFields["publish.name"] = title;
-		extendedFields["server.workspace"] = privateWorkspace;
-		var newDate = new Date();
-		for(var n in fields) {
-			if(!TiddlyWiki.isStandardField(n)) {
-				extendedFields[n] = fields[n];
+		return draftTitle;
+	},
+	createDraftTiddler: function(title, gatheredFields) {
+		var tiddler = store.getTiddler(title);
+		var draftTitle = saveDraftCmd.getDraftTitle(title);
+		var draftTiddler = new Tiddler(draftTitle);
+		if(tiddler) {
+			$.extend(true, draftTiddler, tiddler);
+		} else {
+			$.extend(draftTiddler.fields, config.defaultCustomFields);
+		}
+		for(var fieldName in gatheredFields) {
+			if(TiddlyWiki.isStandardField(fieldName)) {
+				draftTiddler[fieldName] = gatheredFields[fieldName];
+			} else {
+				draftTiddler.fields[fieldName] = gatheredFields[fieldName];
 			}
 		}
-		tiddler = store.saveTiddler(draftTitle, draftTitle, fields.text, config.options.txtUserName,
-			newDate, fields.tags, extendedFields);
-		autoSaveChanges(null, [tiddler]);
+		var currentSpace = tiddlyspace.currentSpace.name;
+		var privateBag = "%0_private".format([currentSpace]);
+		var privateWorkspace = "bags/%0".format([privateBag]);
+		draftTiddler.title = draftTitle;
+		draftTiddler.fields["publish.name"] = title;
+		draftTiddler.fields["server.workspace"] = privateWorkspace;
+		draftTiddler.fields["server.bag"] = privateBag;
+		draftTiddler.fields["server.title"] = draftTitle;
+		draftTiddler.fields["server.page.revision"] = "false";
+		delete draftTiddler.fields["server.etag"];
+		return draftTiddler;
+	},
+	handler: function(ev, src, title) {
+		var tiddler = store.getTiddler(title); // original tiddler
+		var tidEl = story.getTiddler(title);
+		var uiFields = {};
+		story.gatherSaveFields(tidEl, uiFields);
+		var tid = saveDraftCmd.createDraftTiddler(title, uiFields);
+		tid = store.saveTiddler(tid.title, tid.title, tid.text, tid.modifier,
+			new Date(), tid.tags, tid.fields);
+		autoSaveChanges(null, [tid]);
 		story.closeTiddler(title);
-		story.displayTiddler(src, draftTitle);
-		return draftTitle;
+		story.displayTiddler(src, tid.title);
 	}
 };
 
