@@ -3,7 +3,7 @@ http://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.9.2
+// v0.10.1
 //
 // TODO:
 // * ensure all routes are supported
@@ -55,6 +55,7 @@ $.extend(tiddlyweb.Resource.prototype, {
 			dataType: "json",
 			success: function(data, status, xhr) {
 				var resource = self.parse(data);
+				resource.etag = xhr.getResponseHeader("Etag");
 				callback(resource, status, xhr);
 			},
 			error: function(xhr, error, exc) {
@@ -66,40 +67,52 @@ $.extend(tiddlyweb.Resource.prototype, {
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	put: function(callback, errback) {
+		var self = this;
 		var uri = this.route();
 		var data = {};
-		var self = this;
 		$.each(this.data, function(i, item) {
 			var value = self[item];
 			if(value !== undefined) {
 				data[item] = value;
 			}
 		});
-		return $.ajax({
+		var options = {
 			url: uri,
 			type: "PUT",
 			contentType: "application/json",
 			data: $.toJSON(data),
-			success: callback,
+			success: function(data, status, xhr) {
+				callback(self, status, xhr);
+			},
 			error: function(xhr, error, exc) {
 				errback(xhr, error, exc, self);
 			}
-		});
+		};
+		if(this.ajaxSetup) {
+			this.ajaxSetup(options);
+		}
+		return $.ajax(options);
 	},
 	// deletes resource on server
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	"delete": function(callback, errback) {
-		var uri = this.route();
 		var self = this;
-		return $.ajax({
+		var uri = this.route();
+		var options = {
 			url: uri,
 			type: "DELETE",
-			success: callback,
+			success: function(data, status, xhr) {
+				callback(self, status, xhr);
+			},
 			error: function(xhr, error, exc) {
 				errback(xhr, error, exc, self);
 			}
-		});
+		};
+		if(this.ajaxSetup) {
+			this.ajaxSetup(options);
+		}
+		return $.ajax(options);
 	},
 	// returns corresponding instance from raw JSON object (if applicable)
 	parse: function(data) {
@@ -118,7 +131,7 @@ var Container = function(type, name, host) {
 		tiddlyweb.Resource.apply(this, [type, host]);
 		this.name = name;
 		this.desc = "";
-		this.policy = null;
+		this.policy = new tiddlyweb.Policy({});
 	}
 };
 Container.prototype = new tiddlyweb.Resource();
@@ -218,7 +231,27 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 		}
 		return $.extend(tiddler, data);
 	},
-	data: ["created", "modified", "modifier", "tags", "fields", "text", "type"]
+	data: ["modifier", "tags", "fields", "text", "type"],
+	ajaxSetup: function(options) {
+		var self = this;
+		if(this.etag && (options.type == "PUT" || options.type == "DELETE")) {
+			options.beforeSend = function(xhr) {
+				xhr.setRequestHeader("If-Match", self.etag);
+			};
+		}
+		if(options.type == "PUT") {
+			var callback = options.success;
+			options.success = function(data, status, xhr) {
+				var etag = xhr.getResponseHeader("Etag");
+				if(etag) {
+					self.etag = etag;
+					callback(self, status, xhr);
+				} else { // IE
+					self.get(callback, options.error);
+				}
+			};
+		}
+	}
 });
 
 tiddlyweb.Revision = function(id, tiddler) {
